@@ -937,7 +937,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.rsruleprecedence = service.get('RSRulePrecedence', None)
         self.rsruleprecedencepos = service.get('RSRulePrecedencePos', None)
         self.enhancedhealthchecks = service.get('EnhancedHealthChecks', None)
-        rs_min = service.get('RsMinimum', None)
+        rs_min = service.get('RsMinimum', 0)
         self.rsminimum = None if int(rs_min) == 0 else rs_min
 
 
